@@ -89,6 +89,9 @@ void popup_update(Popup_t *self) {
 
   XMoveResizeWindow(self->display, self->window,
 		    self->x, self->y, self->w, self->h);
+
+  XClearArea(self->display, self->window,
+	     0, 0, 0, 0,False);
   XFlush(self->display);
 
   XDrawString(self->display, self->window, self->gc,
@@ -122,7 +125,8 @@ void popup_set_timeout(Popup_t *self, unsigned int ms) {
   self->timeout = now + ms;
 }
 
-void popup_destroy(Popup_t *self) {
+void popup_free(Popup_t *self) {
+  XFreeFont(self->display, self->font);
   XFreeGC(self->display, self->gc);
   free(self);
 }
